==> orc-1.8.7.tar.gz: orc-1.8.7/site/develop/committers.md <==
---
layout: page
title: Project Members
---

## Project Members

{% comment %}
please sort by Apache Id
{% endcomment %}
Name                    | Apache Id    | Role
:---------------------- | :----------- | :---
Aliaksei Sandryhaila    | asandryh     | PMC
Chris Douglas           | cdouglas     | PMC
Chinna Rao Lalam        | chinnaraol   | Committer
Chaoyu Tang             | ctang        | Committer
Carl Steinbach          | cws          | Committer
Daniel Dai              | daijy        | Committer
Dongjoon Hyun           | dongjoon     | PMC Chair
Deepak Majeti           | mdeepak      | PMC
Eugene Koifman          | ekoifman     | PMC
Gang Wu                 | gangwu       | PMC
Alan Gates              | gates        | PMC
Gopal Vijayaraghavan    | gopalv       | PMC
Gunther Hagleitner      | gunther      | Committer
Ashutosh Chauhan        | hashutosh    | Committer
Jesus Camacho Rodriguez | jcamacho     | Committer
Jason Dere              | jdere        | Committer
Jimmy Xiang             | jxiang       | Committer
Kevin Wilfong           | kevinwilfong | Committer
Lars Francke            | larsfrancke  | Committer
Lefty Leverenz          | leftyl       | PMC
Rui Li                  | lirui        | Committer
Mithun Radhakrishnan    | mithun       | Committer
Matthew McCline         | mmccline     | Committer
Sandeep More            | moresandeep  | Committer
Naveen Gangam           | ngangam      | Committer
Owen O'Malley           | omalley      | PMC
Panagiotis Garefalakis  | pgaref       | PMC
Prasanth Jayachandran   | prasanthj    | PMC
Pengcheng Xiong         | pxiong       | Committer
Rajesh Balamohan        | rbalamohan   | Committer
Renat Valiullin         | reval        | Committer
Sergey Shelukhin        | sershe       | Committer
Sergio Pena             | spena        | Committer
Siddharth Seth          | sseth        | Committer
Quanlong Huang          | stigahuang   | Committer
Stephen Walkauskas      | swalkaus     | Committer
Vaibhav Gumashta        | vgumashta    | Committer
Wei Zheng               | weiz         | Committer
William Hyun            | william      | PMC
Xiening Dai             | xndai        | Committer
Xuefu Zhang             | xuefu        | Committer
Ferdinand Xu            | xuf          | Committer
Yongzhi Chen            | ychena       | Committer
Yiqun Zhang             | yqzhang      | Committer
Aihua Xu                | zihuaxu      | Committer

Companies with employees that are committers:

* Alibaba
* Amazon
* Apple
* Cloudera
* Confluent
* Facebook
* Hortonworks
* Huya
* Intel
* LinkedIn
* Microsoft
* Uber
* Vertica
* Workday
* Yahoo

==> orc-2.0.0.tar.gz: orc-2.0.0/site/develop/committers.md <==
---
layout: page
title: Project Members
---

## Project Members

{% comment %}
please sort by Apache Id
{% endcomment %}
Name                    | Apache Id    | Role
:---------------------- | :----------- | :---
Aliaksei Sandryhaila    | asandryh     | PMC
Chris Douglas           | cdouglas     | PMC
Chinna Rao Lalam        | chinnaraol   | Committer
Chaoyu Tang             | ctang        | Committer
Carl Steinbach          | cws          | Committer
Daniel Dai              | daijy        | Committer
Dongjoon Hyun           | dongjoon     | PMC
Deepak Majeti           | mdeepak      | PMC
Eugene Koifman          | ekoifman     | PMC
Gang Wu                 | gangwu       | PMC
Gopal Vijayaraghavan    | gopalv       | PMC
Gunther Hagleitner      | gunther      | Committer
Ashutosh Chauhan        | hashutosh    | Committer
Jesus Camacho Rodriguez | jcamacho     | Committer
Jason Dere              | jdere        | Committer
Jimmy Xiang             | jxiang       | Committer
Kevin Wilfong           | kevinwilfong | Committer
Lars Francke            | larsfrancke  | Committer
Lefty Leverenz          | leftyl       | PMC
Rui Li                  | lirui        | Committer
Mithun Radhakrishnan    | mithun       | Committer
Matthew McCline         | mmccline     | Committer
Sandeep More            | moresandeep  | Committer
Naveen Gangam           | ngangam      | Committer
Owen O'Malley           | omalley      | PMC
Panagiotis Garefalakis  | pgaref       | PMC
Pavan Lanka             | planka       | PMC
Prasanth Jayachandran   | prasanthj    | PMC
Pengcheng Xiong         | pxiong       | Committer
Rajesh Balamohan        | rbalamohan   | Committer
Renat Valiullin         | reval        | Committer
Sergey Shelukhin        | sershe       | Committer
Sergio Pena             | spena        | Committer
Siddharth Seth          | sseth        | Committer
Quanlong Huang          | stigahuang   | Committer
Stephen Walkauskas      | swalkaus     | Committer
Vaibhav Gumashta        | vgumashta    | Committer
Wei Zheng               | weiz         | Committer
William Hyun            | william      | PMC Chair
Xin Zhang               | xinzhang     | Committer
Xiening Dai             | xndai        | Committer
Xuefu Zhang             | xuefu        | Committer
Ferdinand Xu            | xuf          | Committer
Yongzhi Chen            | ychena       | Committer
Yiqun Zhang             | yqzhang      | PMC
Aihua Xu                | zihuaxu      | Committer

## Emiritus Members

{% comment %}
please sort by Apache Id
{% endcomment %}
Name                    | Apache Id
:---------------------- | :-----------
Alan Gates              | gates

Companies with employees that are committers:

* Alibaba
* Amazon
* Apple
* Cloudera
* Confluent
* Facebook
* Hortonworks
* Huya
* Intel
* LinkedIn
* Microsoft
* Uber
* Vertica
* Workday
* Yahoo
